--------------------------
README file for PyICU_BiDi
--------------------------

.. contents::

Documentation
-------------

Please read the source or create the html-documentation using the following command::

	``python setup.py build_sphinx``


Changelog
---------

2014-06-26 Version 0.0.1:

Initial release by science + computing ag as open source.
Unfortunately almost completely undocumented. Tested only on
Windows. It does not work on Linux due to byte order problems.
